@@ -616,7 +616,7 @@ static String gv_nls_de_UTF_8_dat [] = {
 "GV*strings.copyrightTranslation:	Markus Steinborn <gnugv_maintainer@yahoo.de>",
 0};
 
-String* getI18N(char* locale)
+static String* getI18N(char* locale)
 {
    if (!strcmp(locale, "noint:de")) return gv_nls_noint_de_dat;
    if (!strcmp(locale, "ko_KR.UTF-8")) return gv_nls_ko_KR_UTF_8_dat;
